@@ -1,3 +1,3 @@
-from nlex.wrap import (
+from .wrap import (
     NLexWrappedObject, NLexTokenizer
 )
